﻿using System;
using OpenBveApi.Runtime;

namespace OpenbveFcmbTrainPlugin
{
    /// <summary>A device handling the headlights.</summary>
    internal class Headlights : Device
    {
        /// <summary>Is called when the device state should be updated.</summary>
        /// <param name="train">The current train.</param>
        /// <param name="route">The current route.</param>
        /// <param name="init">Whether the device should initialize.</param>
        /// <param name="elapsedTime">The time elapsed since the previous call.</param>
        internal override void Update(Train train, Route route, bool init, Time elapsedTime)
        {
            // Turn off headlights if the reverser is not set to forward
            if (train.PhysicalHandles.Reverser < 1)
            {
                train.HeadlightState = 0;
            }
        }

        /// <summary>Is called when the state of a key changes.</summary>
        /// <param name="key">The key.</param>
        /// <param name="pressed">Whether the key is pressed or released.</param>
        /// <param name="train">The current train.</param>
        internal override void KeyChange(VirtualKeys key, bool pressed, Train train)
        {
            if (pressed)
            {
                switch (key)
                {
                    case VirtualKeys.Headlights:
                        // Cycle through headlight states
                        if (!OpenbveFcmbTrainPlugin.KeysPressed[(int)key])
                        {
                            if (train.PhysicalHandles.Reverser == 1)
                            {
                                if (train.HeadlightState < train.Specs.HeadlightStates)
                                {
                                    train.HeadlightState++;
                                }
                                else
                                {
                                    train.HeadlightState = 0;
                                }
                            }
                        }
                        break;
                }
            }
        }
    }
}

